slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSGetType

Gets the EPS type as a string from the EPS object.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSGetType(EPS eps,EPSType *type)

Not Collective

### Input Parameter

| eps | - the eigensolver context

### Output Parameter

| type | - name of EPS method

### See Also

EPSSetType()

### Level

intermediate

### Location

src/eps/interface/epsbasic.c

### Examples

src/eps/tutorials/ex1.c.html
src/eps/tutorials/ex1f.F.html
src/eps/tutorials/ex1f90.F90.html
src/eps/tutorials/ex2.c.html
src/eps/tutorials/ex3.c.html
src/eps/tutorials/ex4.c.html
src/eps/tutorials/ex5.c.html
src/eps/tutorials/ex6f90.F90.html
src/eps/tutorials/ex7.c.html
src/eps/tutorials/ex9.c.html
src/eps/tutorials/ex10.c.html
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages